@@ -15,12 +15,12 @@ use std::fmt::Write;
 use eyre::Context;
 use tracing::instrument;
 
+use crate::core::effects::Effects;
 use crate::core::eventlog::{
     is_gc_ref, CommitActivityStatus, EventCursor, EventLogDb, EventReplayer,
 };
 use crate::core::formatting::Pluralize;
 use crate::git::{NonZeroOid, Reference, Repo};
-use crate::tui::Effects;
 
 fn find_dangling_references<'repo>(
     repo: &'repo Repo,
@@ -65,7 +65,15 @@ fn find_dangling_references<'repo>(
 /// * `commit_oid`: The commit OID to mark as reachable.
 #[instrument]
 pub fn mark_commit_reachable(repo: &Repo, commit_oid: NonZeroOid) -> eyre::Result<()> {
-    let ref_name = format!("refs/branchless/{}", commit_oid.to_string());
+    if !repo.get_config_path().exists() {
+        // Don't create garbage collection references for users who don't appear
+        // to have run `git branchless init` in this repository, since they may
+        // not want their tooling (such as `tig`) polluted by extra references.
+        // See https://github.com/arxanas/git-branchless/issues/183
+        return Ok(());
+    }
+
+    let ref_name = format!("refs/branchless/{}", commit_oid);
     eyre::ensure!(
         Reference::is_valid_name(&ref_name),
         format!("Invalid ref name to mark commit as reachable: {}", ref_name)
