@@ -10,9 +10,9 @@ use path_slash::PathExt;
 use tracing::{instrument, warn};
 
 use crate::core::config::{get_core_hooks_path, get_default_branch_name};
+use crate::core::effects::Effects;
 use crate::git::{Config, ConfigRead, ConfigWrite, GitRunInfo, GitVersion, Repo};
 use crate::opts::write_man_pages;
-use crate::tui::Effects;
 
 const ALL_HOOKS: &[(&str, &str)] = &[
     (
@@ -24,8 +24,8 @@ git branchless hook-post-commit "$@"
     (
         "post-merge",
         r#"
-        git branchless hook-post-merge "$@"
-        "#,
+git branchless hook-post-merge "$@"
+"#,
     ),
     (
         "post-rewrite",
@@ -60,15 +60,18 @@ echo 'branchless: This is a bug. Please report it.'
 ];
 
 const ALL_ALIASES: &[(&str, &str)] = &[
-    ("smartlog", "smartlog"),
-    ("sl", "smartlog"),
+    // Re-enable these aliases when they no longer clobber user aliases:
+    // ("amend", "amend"),
+    // ("co", "checkout"),
     ("hide", "hide"),
-    ("unhide", "unhide"),
-    ("prev", "prev"),
-    ("next", "next"),
-    ("restack", "restack"),
-    ("undo", "undo"),
     ("move", "move"),
+    ("next", "next"),
+    ("prev", "prev"),
+    ("restack", "restack"),
+    ("sl", "smartlog"),
+    ("smartlog", "smartlog"),
+    ("undo", "undo"),
+    ("unhide", "unhide"),
 ];
 
 #[derive(Debug)]
@@ -100,17 +103,23 @@ const SHEBANG: &str = "#!/bin/sh";
 const UPDATE_MARKER_START: &str = "## START BRANCHLESS CONFIG";
 const UPDATE_MARKER_END: &str = "## END BRANCHLESS CONFIG";
 
+fn append_hook(new_lines: &mut String, hook_contents: &str) {
+    new_lines.push_str(UPDATE_MARKER_START);
+    new_lines.push('\n');
+    new_lines.push_str(hook_contents);
+    new_lines.push_str(UPDATE_MARKER_END);
+    new_lines.push('\n');
+}
+
 fn update_between_lines(lines: &str, updated_lines: &str) -> String {
     let mut new_lines = String::new();
+    let mut found_marker = false;
     let mut is_ignoring_lines = false;
     for line in lines.lines() {
         if line == UPDATE_MARKER_START {
+            found_marker = true;
             is_ignoring_lines = true;
-            new_lines.push_str(UPDATE_MARKER_START);
-            new_lines.push('\n');
-            new_lines.push_str(updated_lines);
-            new_lines.push_str(UPDATE_MARKER_END);
-            new_lines.push('\n');
+            append_hook(&mut new_lines, updated_lines);
         } else if line == UPDATE_MARKER_END {
             is_ignoring_lines = false;
         } else if !is_ignoring_lines {
@@ -120,6 +129,8 @@ fn update_between_lines(lines: &str, updated_lines: &str) -> String {
     }
     if is_ignoring_lines {
         warn!("Unterminated branchless config comment in hook");
+    } else if !found_marker {
+        append_hook(&mut new_lines, updated_lines);
     }
     new_lines
 }
@@ -194,6 +205,21 @@ fn install_hooks(effects: &Effects, repo: &Repo) -> eyre::Result<()> {
         )?;
         install_hook(repo, hook_type, hook_script)?;
     }
+
+    let hooks_path: Option<PathBuf> = repo.get_readonly_config()?.get("core.hooksPath")?;
+    if let Some(hooks_path) = hooks_path {
+        writeln!(
+            effects.get_output_stream(),
+            "{}: the configuration value core.hooksPath was set to: {}",
+            style("Warning").yellow().bold(),
+            hooks_path.to_string_lossy()
+        )?;
+        writeln!(
+            effects.get_output_stream(),
+            "The Git hooks above may have been installed to an unexpected location."
+        )?;
+    }
+
     Ok(())
 }
 
@@ -286,8 +312,11 @@ fn install_aliases(
     }
 
     let version_str = git_run_info
-        .run_silent(repo, None, &["version"])
-        .wrap_err("Determining Git version")?;
+        .run_silent(repo, None, &["version"], Default::default())
+        .wrap_err("Determining Git version")?
+        .stdout;
+    let version_str =
+        String::from_utf8(version_str).wrap_err("Decoding stdout from Git subprocess")?;
     let version_str = version_str.trim();
     let version: GitVersion = version_str
         .parse()
@@ -415,6 +444,7 @@ fn set_configs(
 
     config.set("branchless.core.mainBranch", main_branch_name)?;
     config.set("advice.detachedHead", false)?;
+    config.set("log.excludeDecoration", "refs/branchless/*")?;
 
     Ok(())
 }
