@@ -63,17 +63,15 @@ use tracing::{instrument, warn};
 
 use crate::commands::smartlog::smartlog;
 use crate::core::config::get_restack_preserve_timestamps;
+use crate::core::dag::{resolve_commits, sort_commit_set, CommitSet, Dag, ResolveCommitsResult};
+use crate::core::effects::Effects;
 use crate::core::eventlog::{EventCursor, EventLogDb, EventReplayer};
 use crate::core::rewrite::{
     execute_rebase_plan, find_abandoned_children, find_rewrite_target, move_branches,
     BuildRebasePlanOptions, ExecuteRebasePlanOptions, ExecuteRebasePlanResult, RebasePlanBuilder,
 };
-use crate::git::{
-    resolve_commits, sort_commit_set, CommitSet, Dag, GitRunInfo, NonZeroOid, Repo,
-    ResolveCommitsResult,
-};
+use crate::git::{GitRunInfo, NonZeroOid, Repo};
 use crate::opts::MoveOptions;
-use crate::tui::Effects;
 
 #[instrument(skip(commits))]
 fn restack_commits(
@@ -238,7 +236,6 @@ pub fn restack(
     let conn = repo.get_db_conn()?;
     let event_log_db = EventLogDb::new(&conn)?;
     let event_tx_id = event_log_db.make_transaction_id(now, "restack")?;
-    let head_oid = repo.get_head_info()?.oid;
 
     let references_snapshot = repo.get_references_snapshot()?;
     let event_replayer = EventReplayer::from_event_log_db(effects, &repo, &event_log_db)?;
@@ -312,15 +309,6 @@ pub fn restack(
         return Ok(result);
     }
 
-    let result = match head_oid {
-        Some(head_oid) => git_run_info.run(
-            effects,
-            Some(event_tx_id),
-            &["checkout", &head_oid.to_string()],
-        )?,
-        None => result,
-    };
-
-    smartlog(effects, &Default::default())?;
+    smartlog(effects, git_run_info, &Default::default())?;
     Ok(result)
 }
