@@ -4,7 +4,7 @@
 //! time and inverting them.
 
 use std::convert::TryInto;
-use std::ffi::{OsStr, OsString};
+use std::ffi::OsString;
 use std::fmt::Write;
 use std::io::{stdin, BufRead, BufReader, Read};
 use std::sync::mpsc::{channel, Receiver, Sender, TryRecvError};
@@ -19,15 +19,17 @@ use eyre::Context;
 use tracing::instrument;
 
 use crate::commands::smartlog::{make_smartlog_graph, render_graph};
+use crate::core::dag::Dag;
+use crate::core::effects::Effects;
 use crate::core::eventlog::{Event, EventCursor, EventLogDb, EventReplayer, EventTransactionId};
 use crate::core::formatting::{printable_styled_string, Pluralize, StyledStringBuilder};
-use crate::core::metadata::{
-    BranchesProvider, CommitMessageProvider, CommitOidProvider, DifferentialRevisionProvider,
-    ObsolescenceExplanationProvider, RelativeTimeProvider,
+use crate::core::node_descriptors::{
+    BranchesDescriptor, CommitMessageDescriptor, CommitOidDescriptor,
+    DifferentialRevisionDescriptor, ObsolescenceExplanationDescriptor, RelativeTimeDescriptor,
 };
 use crate::declare_views;
-use crate::git::{CategorizedReferenceName, Dag, GitRunInfo, MaybeZeroOid, Repo};
-use crate::tui::{with_siv, Effects, SingletonView};
+use crate::git::{check_out_commit, CategorizedReferenceName, GitRunInfo, MaybeZeroOid, Repo};
+use crate::tui::{with_siv, SingletonView};
 
 fn render_cursor_smartlog(
     effects: &Effects,
@@ -46,12 +48,12 @@ fn render_cursor_smartlog(
         &graph,
         references_snapshot.head_oid,
         &mut [
-            &mut CommitOidProvider::new(true)?,
-            &mut RelativeTimeProvider::new(repo, SystemTime::now())?,
-            &mut ObsolescenceExplanationProvider::new(event_replayer, event_cursor)?,
-            &mut BranchesProvider::new(repo, &references_snapshot)?,
-            &mut DifferentialRevisionProvider::new(repo)?,
-            &mut CommitMessageProvider::new()?,
+            &mut CommitOidDescriptor::new(true)?,
+            &mut RelativeTimeDescriptor::new(repo, SystemTime::now())?,
+            &mut ObsolescenceExplanationDescriptor::new(event_replayer, event_cursor)?,
+            &mut BranchesDescriptor::new(repo, &references_snapshot)?,
+            &mut DifferentialRevisionDescriptor::new(repo)?,
+            &mut CommitMessageDescriptor::new()?,
         ],
     )?;
     Ok(result)
@@ -382,11 +384,11 @@ fn select_past_event(
                 )],
                 Some((event_id, events)) => {
                     let event_description_lines = describe_events_numbered(repo, events)?;
-                    let relative_time_provider = RelativeTimeProvider::new(repo, now)?;
+                    let relative_time_provider = RelativeTimeDescriptor::new(repo, now)?;
                     let relative_time = if relative_time_provider.is_enabled() {
                         format!(
                             " ({} ago)",
-                            RelativeTimeProvider::describe_time_delta(
+                            RelativeTimeDescriptor::describe_time_delta(
                                 now,
                                 events[0].get_timestamp()
                             )?
@@ -685,6 +687,7 @@ fn undo_events(
     }
     .to_string();
 
+    let mut result = 0;
     for event in inverse_events.into_iter() {
         match event {
             Event::RefUpdateEvent {
@@ -700,17 +703,17 @@ fn undo_events(
                 // this case, rather than just update `HEAD` (and be left with a
                 // dirty working copy). The `Git` command will update the event
                 // log appropriately, as it will invoke our hooks.
-                git_run_info
-                    .run(
-                        effects,
-                        Some(event_tx_id),
-                        &[
-                            OsStr::new("checkout"),
-                            OsStr::new("--detach"),
-                            target_oid.as_os_str(),
-                        ],
-                    )
-                    .wrap_err("Updating to previous HEAD location")?;
+                let exit_code = check_out_commit(
+                    effects,
+                    git_run_info,
+                    Some(event_tx_id),
+                    Some(target_oid.as_os_str()),
+                    &["--detach"],
+                )
+                .wrap_err("Updating to previous HEAD location")?;
+                if exit_code != 0 {
+                    result = exit_code;
+                }
             }
             Event::RefUpdateEvent {
                 timestamp: _,
@@ -774,7 +777,7 @@ fn undo_events(
         "Applied {}.",
         num_inverse_events
     )?;
-    Ok(0)
+    Ok(result)
 }
 
 /// Restore the repository to a previous state interactively.
@@ -827,9 +830,10 @@ pub mod testing {
 
     use cursive::{CursiveRunnable, CursiveRunner};
 
+    use crate::core::dag::Dag;
+    use crate::core::effects::Effects;
     use crate::core::eventlog::{EventCursor, EventLogDb, EventReplayer};
-    use crate::git::{Dag, GitRunInfo, Repo};
-    use crate::tui::Effects;
+    use crate::git::{GitRunInfo, Repo};
 
     pub fn select_past_event(
         siv: CursiveRunner<CursiveRunnable>,
