@@ -690,7 +690,7 @@ mod in_memory {
         // produce a spurious abandoned-branch warning.
         let post_rewrite_stdin: String = rewritten_oids
             .iter()
-            .map(|(old_oid, new_oid)| format!("{} {}\n", old_oid.to_string(), new_oid.to_string()))
+            .map(|(old_oid, new_oid)| format!("{} {}\n", old_oid, new_oid))
             .collect();
         let post_rewrite_stdin = OsString::from(post_rewrite_stdin);
         git_run_info.run_hook(
@@ -725,6 +725,7 @@ mod on_disk {
 
     use crate::core::effects::{Effects, OperationType};
     use crate::core::rewrite::plan::RebasePlan;
+    use crate::core::rewrite::rewrite_hooks::save_original_head_info;
     use crate::git::{GitRunInfo, Repo};
 
     use super::ExecuteRebasePlanOptions;
@@ -811,6 +812,8 @@ mod on_disk {
             )
             .wrap_err_with(|| format!("Writing head-name to: {:?}", &head_name_file_path))?;
 
+            save_original_head_info(repo, &head_info)?;
+
             // Dummy `head` file. We will `reset` to the appropriate commit as soon as
             // we start the rebase.
             let rebase_merge_head_file_path = rebase_state_dir.join("head");
