@@ -42,30 +42,103 @@ pub struct MoveOptions {
     pub dump_rebase_plan: bool,
 }
 
+/// Options for traversing commits.
+#[derive(Args, Debug)]
+pub struct TraverseCommitsOptions {
+    /// The number of commits to traverse.
+    ///
+    /// If not provided, defaults to 1.
+    pub num_commits: Option<usize>,
+
+    /// Traverse as many commits as possible.
+    #[clap(short = 'a', long = "all")]
+    pub all_the_way: bool,
+
+    /// Move the specified number of branches rather than commits.
+    #[clap(short = 'b', long = "branch")]
+    pub move_by_branches: bool,
+
+    /// When encountering multiple next commits, choose the oldest.
+    #[clap(short = 'o', long = "oldest")]
+    pub oldest: bool,
+
+    /// When encountering multiple next commits, choose the newest.
+    #[clap(short = 'n', long = "newest", conflicts_with("oldest"))]
+    pub newest: bool,
+
+    /// When encountering multiple next commits, interactively prompt which to
+    /// advance to.
+    #[clap(
+        short = 'i',
+        long = "interactive",
+        conflicts_with("newest"),
+        conflicts_with("oldest")
+    )]
+    pub interactive: bool,
+
+    /// If the local changes conflict with the destination commit, attempt to
+    /// merge them.
+    #[clap(short = 'm', long = "merge")]
+    pub merge: bool,
+
+    /// If the local changes conflict with the destination commit, discard them.
+    /// (Use with caution!)
+    #[clap(short = 'f', long = "force", conflicts_with("merge"))]
+    pub force: bool,
+}
+
+/// Options for checking out a commit.
+#[derive(Args, Debug)]
+pub struct CheckoutOptions {
+    /// Interactively select a commit to check out.
+    #[clap(short = 'i', long = "interactive")]
+    pub interactive: bool,
+
+    /// When checking out the target commit, also create a branch with the
+    /// provided name pointing to that commit.
+    #[clap(short = 'b', long = "branch")]
+    pub branch_name: Option<String>,
+
+    /// Forcibly switch commits, discarding any working copy changes if
+    /// necessary.
+    #[clap(short = 'f', long = "force")]
+    pub force: bool,
+
+    /// If the current working copy changes do not apply cleanly to the
+    /// target commit, start merge conflict resolution instead of aborting.
+    #[clap(short = 'm', long = "merge", conflicts_with("force"))]
+    pub merge: bool,
+
+    /// The commit or branch to check out.
+    ///
+    /// If this is not provided, then interactive commit selection starts as
+    /// if `--interactive` were passed.
+    ///
+    /// If this is provided and the `--interactive` flag is passed, this
+    /// text is used to pre-fill the interactive commit selector.
+    pub target: Option<String>,
+}
+
 /// FIXME: write man-page text
 #[derive(Parser)]
 pub enum Command {
-    /// Initialize the branchless workflow for this repository.
-    Init {
-        /// Uninstall the branchless workflow instead of initializing it.
-        #[clap(long = "uninstall")]
-        uninstall: bool,
-
-        /// Use the provided name as the name of the main branch.
-        ///
-        /// If not set, it will be auto-detected. If it can't be auto-detected,
-        /// then you will be prompted to enter a value for the main branch name.
-        #[clap(long = "main-branch", conflicts_with = "uninstall")]
-        main_branch_name: Option<String>,
+    /// Amend the current HEAD commit.
+    Amend {
+        /// Options for moving commits.
+        #[clap(flatten)]
+        move_options: MoveOptions,
     },
 
-    /// Display a nice graph of the commits you've recently worked on.
-    Smartlog {
-        /// Also show commits which have been hidden.
-        #[clap(long = "hidden")]
-        show_hidden_commits: bool,
+    /// Check out a given commit.
+    Checkout {
+        /// Options for checking out a commit.
+        #[clap(flatten)]
+        checkout_options: CheckoutOptions,
     },
 
+    /// Run internal garbage collection.
+    Gc,
+
     /// Hide the provided commits from the smartlog.
     Hide {
         /// Zero or more commits to hide.
@@ -79,38 +152,69 @@ pub enum Command {
         recursive: bool,
     },
 
-    /// Unhide previously-hidden commits from the smartlog.
-    Unhide {
-        /// Zero or more commits to unhide.
-        ///
-        /// Can either be hashes, like `abc123`, or ref-specs, like `HEAD^`.
-        commits: Vec<String>,
-
-        /// Also recursively unhide all children commits of the provided commits.
-        #[clap(short = 'r', long = "recursive")]
-        recursive: bool,
+    /// Internal use.
+    HookDetectEmptyCommit {
+        /// The OID of the commit currently being applied, to be checked for emptiness.
+        old_commit_oid: String,
     },
 
-    /// Move to an earlier commit in the current stack.
-    Prev {
-        /// The number of commits backward to go.
-        num_commits: Option<isize>,
+    /// Internal use.
+    HookPreAutoGc,
+
+    /// Internal use.
+    HookPostCheckout {
+        /// The previous commit OID.
+        previous_commit: String,
+
+        /// The current commit OID.
+        current_commit: String,
+
+        /// Whether or not this was a branch checkout (versus a file checkout).
+        is_branch_checkout: isize,
     },
 
-    /// Move to a later commit in the current stack.
-    Next {
-        /// The number of commits forward to go.
+    /// Internal use.
+    HookPostCommit,
+
+    /// Internal use.
+    HookPostMerge {
+        /// Whether or not this is a squash merge. See githooks(5).
+        is_squash_merge: isize,
+    },
+
+    /// Internal use.
+    HookPostRewrite {
+        /// One of `amend` or `rebase`.
+        rewrite_type: String,
+    },
+
+    /// Internal use.
+    HookReferenceTransaction {
+        /// One of `prepared`, `committed`, or `aborted`. See githooks(5).
+        transaction_state: String,
+    },
+
+    /// Internal use.
+    HookRegisterExtraPostRewriteHook,
+
+    /// Internal use.
+    HookSkipUpstreamAppliedCommit {
+        /// The OID of the commit that was skipped.
+        commit_oid: String,
+    },
+
+    /// Initialize the branchless workflow for this repository.
+    Init {
+        /// Uninstall the branchless workflow instead of initializing it.
+        #[clap(long = "uninstall")]
+        uninstall: bool,
+
+        /// Use the provided name as the name of the main branch.
         ///
-        /// If not provided, defaults to 1.
-        num_commits: Option<isize>,
-
-        /// When encountering multiple next commits, choose the oldest.
-        #[clap(short = 'o', long = "oldest")]
-        oldest: bool,
-
-        /// When encountering multiple next commits, choose the newest.
-        #[clap(short = 'n', long = "newest", conflicts_with("oldest"))]
-        newest: bool,
+        /// If not set, it will be auto-detected. If it can't be auto-detected,
+        /// then you will be prompted to enter a value for the main branch name.
+        #[clap(long = "main-branch", conflicts_with = "uninstall")]
+        main_branch_name: Option<String>,
     },
 
     /// Move a subtree of commits from one location to another.
@@ -144,6 +248,20 @@ pub enum Command {
         move_options: MoveOptions,
     },
 
+    /// Move to a later commit in the current stack.
+    Next {
+        /// Options for traversing commits.
+        #[clap(flatten)]
+        traverse_commits_options: TraverseCommitsOptions,
+    },
+
+    /// Move to an earlier commit in the current stack.
+    Prev {
+        /// Options for traversing commits.
+        #[clap(flatten)]
+        traverse_commits_options: TraverseCommitsOptions,
+    },
+
     /// Fix up commits abandoned by a previous rewrite operation.
     Restack {
         /// The IDs of the abandoned commits whose descendants should be
@@ -155,11 +273,27 @@ pub enum Command {
         move_options: MoveOptions,
     },
 
+    /// Display a nice graph of the commits you've recently worked on.
+    Smartlog {
+        /// Also show commits which have been hidden.
+        #[clap(long = "hidden")]
+        show_hidden_commits: bool,
+    },
+
     /// Browse or return to a previous state of the repository.
     Undo,
 
-    /// Run internal garbage collection.
-    Gc,
+    /// Unhide previously-hidden commits from the smartlog.
+    Unhide {
+        /// Zero or more commits to unhide.
+        ///
+        /// Can either be hashes, like `abc123`, or ref-specs, like `HEAD^`.
+        commits: Vec<String>,
+
+        /// Also recursively unhide all children commits of the provided commits.
+        #[clap(short = 'r', long = "recursive")]
+        recursive: bool,
+    },
 
     /// Wrap a Git command inside a branchless transaction.
     Wrap {
@@ -171,57 +305,6 @@ pub enum Command {
         #[clap(subcommand)]
         command: WrappedCommand,
     },
-
-    /// Internal use.
-    HookPreAutoGc,
-
-    /// Internal use.
-    HookPostRewrite {
-        /// One of `amend` or `rebase`.
-        rewrite_type: String,
-    },
-
-    /// Internal use.
-    HookRegisterExtraPostRewriteHook,
-
-    /// Internal use.
-    HookDetectEmptyCommit {
-        /// The OID of the commit currently being applied, to be checked for emptiness.
-        old_commit_oid: String,
-    },
-
-    /// Internal use.
-    HookSkipUpstreamAppliedCommit {
-        /// The OID of the commit that was skipped.
-        commit_oid: String,
-    },
-
-    /// Internal use.
-    HookPostCheckout {
-        /// The previous commit OID.
-        previous_commit: String,
-
-        /// The current commit OID.
-        current_commit: String,
-
-        /// Whether or not this was a branch checkout (versus a file checkout).
-        is_branch_checkout: isize,
-    },
-
-    /// Internal use.
-    HookPostCommit,
-
-    /// Internal use.
-    HookPostMerge {
-        /// Whether or not this is a squash merge. See githooks(5).
-        is_squash_merge: isize,
-    },
-
-    /// Internal use.
-    HookReferenceTransaction {
-        /// One of `prepared`, `committed`, or `aborted`. See githooks(5).
-        transaction_state: String,
-    },
 }
 
 /// Whether to display terminal colors.
@@ -305,7 +388,6 @@ fn generate_man_page(man1_dir: &Path, name: &str, command: &App) -> std::io::Res
         manual = manual.arg(Arg::new(&format!("[{}]", arg.get_name().to_uppercase())));
     }
 
-    // The below doesn't compile as of `clap` `v3.0.0-beta.5`.
     for flag in command.get_opts() {
         let opt = man::Opt::new(flag.get_name());
         let opt = match flag.get_short() {
@@ -316,7 +398,7 @@ fn generate_man_page(man1_dir: &Path, name: &str, command: &App) -> std::io::Res
             Some(long) => opt.long(long),
             None => opt,
         };
-        let opt = match flag.get_about() {
+        let opt = match flag.get_help() {
             Some(help) => opt.help(help),
             None => opt,
         };
