@@ -1,4 +1,4 @@
-use branchless::testing::{make_git, GitRunOptions};
+use branchless::testing::{make_git, GitInitOptions, GitRunOptions};
 
 /// Remove some of the output from `git rebase`, as it seems to be
 /// non-deterministic as to whether or not it appears.
@@ -30,7 +30,6 @@ fn test_restack_amended_commit() -> eyre::Result<()> {
     }
 
     git.init_repo()?;
-    git.run(&["config", "branchless.restack.preserveTimestamps", "true"])?;
 
     git.detach_head()?;
     git.commit_file("test1", 1)?;
@@ -63,7 +62,6 @@ fn test_restack_amended_commit() -> eyre::Result<()> {
         branchless: running command: <git-executable> rebase --continue
         Finished restacking commits.
         No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout 024c35ce32dae6b12e981963465ee8a62b7eff9b
         O f777ecc9 (master) create initial.txt
         |
         @ 024c35ce amend test1.txt
@@ -86,7 +84,6 @@ fn test_restack_consecutive_rewrites() -> eyre::Result<()> {
     }
 
     git.init_repo()?;
-    git.run(&["config", "branchless.restack.preserveTimestamps", "true"])?;
 
     git.detach_head()?;
     git.commit_file("test1", 1)?;
@@ -106,7 +103,6 @@ fn test_restack_consecutive_rewrites() -> eyre::Result<()> {
         branchless: running command: <git-executable> rebase --continue
         Finished restacking commits.
         No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout 662b451fb905b92404787e024af717ced49e3045
         O f777ecc9 (master) create initial.txt
         |
         @ 662b451f amend test1.txt v2
@@ -125,7 +121,6 @@ fn test_move_abandoned_branch() -> eyre::Result<()> {
     let git = make_git()?;
 
     git.init_repo()?;
-    git.run(&["config", "branchless.restack.preserveTimestamps", "true"])?;
 
     git.commit_file("test1", 1)?;
     git.detach_head()?;
@@ -139,7 +134,6 @@ fn test_move_abandoned_branch() -> eyre::Result<()> {
         No abandoned commits to restack.
         branchless: processing 1 update: branch master
         Finished restacking branches.
-        branchless: running command: <git-executable> checkout 662b451fb905b92404787e024af717ced49e3045
         :
         @ 662b451f (master) amend test1.txt v2
         "###);
@@ -183,7 +177,6 @@ fn test_amended_initial_commit() -> eyre::Result<()> {
         branchless: running command: <git-executable> rebase --continue
         Finished restacking commits.
         No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout 9a9f929a0d4f052ff5d58bedd97b2f761120f8ed
         @ 9a9f929a new initial commit
         |
         O 6d85943b (master) create test1.txt
@@ -202,7 +195,6 @@ fn test_restack_amended_master() -> eyre::Result<()> {
     }
 
     git.init_repo()?;
-    git.run(&["config", "branchless.restack.preserveTimestamps", "true"])?;
 
     git.commit_file("test1", 1)?;
     git.commit_file("test2", 2)?;
@@ -219,7 +211,6 @@ fn test_restack_amended_master() -> eyre::Result<()> {
         branchless: running command: <git-executable> rebase --continue
         Finished restacking commits.
         No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout ae94dc2a748bc0965c88fcf3edac2e30074ff7e2
         :
         @ ae94dc2a amended test1
         |
@@ -291,7 +282,11 @@ fn test_restack_aborts_during_rebase_conflict() -> eyre::Result<()> {
 fn test_restack_multiple_amended() -> eyre::Result<()> {
     let git = make_git()?;
 
+    if !git.supports_committer_date_is_author_date()? {
+        return Ok(());
+    }
     git.init_repo()?;
+
     git.detach_head()?;
     git.commit_file("test1", 1)?;
     git.commit_file("test2", 2)?;
@@ -312,16 +307,15 @@ fn test_restack_multiple_amended() -> eyre::Result<()> {
         branchless: running command: <git-executable> rebase --continue
         Finished restacking commits.
         No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout 62fc20d2a290daea0d52bdc2ed2ad4be6491010e
         O f777ecc9 (master) create initial.txt
         |
         @ 62fc20d2 create test1.txt
         |
         o 22f39285 test2 amended
         |
-        o 2fdee375 test3 amended
+        o 8e06b96d test3 amended
         |
-        o c2dfde02 create test4.txt
+        o f5644e32 create test4.txt
         "###);
     }
 
@@ -374,29 +368,17 @@ fn test_restack_single_of_many_commits() -> eyre::Result<()> {
     {
         let (stdout, stderr) = git.run(&["restack", "--on-disk", &test2_oid.to_string()])?;
         insta::assert_snapshot!(stderr, @r###"
-        Executing: git branchless hook-register-extra-post-rewrite-hook
         branchless: processing 1 update: ref HEAD
         branchless: processing 1 update: ref HEAD
-        branchless: processed commit: bb7d4b2a create test3.txt
+        branchless: processed commit: 944f78da create test3.txt
         Executing: git branchless hook-detect-empty-commit 70deb1e28791d8e7dd5a1f0c871a51b91282562f
+        Executing: git branchless hook-register-extra-post-rewrite-hook
         branchless: processing 1 rewritten commit
         branchless: running command: <git-executable> checkout 3bd716d57489779ab1daf446f80e66e90b56ead7
-        Previous HEAD position was bb7d4b2 create test3.txt
+        Previous HEAD position was 944f78d create test3.txt
         branchless: processing 1 update: ref HEAD
         HEAD is now at 3bd716d updated test4
         branchless: processing checkout
-        Successfully rebased and updated detached HEAD.
-        branchless: processing 1 update: ref HEAD
-        HEAD is now at 3bd716d updated test4
-        branchless: processing checkout
-        "###);
-        insta::assert_snapshot!(stdout, @r###"
-        branchless: running command: <git-executable> diff --quiet
-        Calling Git for on-disk rebase...
-        branchless: running command: <git-executable> rebase --continue
-        Finished restacking commits.
-        No abandoned branches to restack.
-        branchless: running command: <git-executable> checkout 3bd716d57489779ab1daf446f80e66e90b56ead7
         :
         O 62fc20d2 (master) create test1.txt
         |\
@@ -404,7 +386,27 @@ fn test_restack_single_of_many_commits() -> eyre::Result<()> {
         |\
         | o 7357d2b7 updated test2
         | |
-        | o bb7d4b2a create test3.txt
+        | o 944f78da create test3.txt
+        |
+        x bf0d52a6 (rewritten as 3bd716d5) create test4.txt
+        |
+        o 848121cb create test5.txt
+        Successfully rebased and updated detached HEAD.
+        "###);
+        insta::assert_snapshot!(stdout, @r###"
+        branchless: running command: <git-executable> diff --quiet
+        Calling Git for on-disk rebase...
+        branchless: running command: <git-executable> rebase --continue
+        Finished restacking commits.
+        No abandoned branches to restack.
+        :
+        O 62fc20d2 (master) create test1.txt
+        |\
+        | @ 3bd716d5 updated test4
+        |\
+        | o 7357d2b7 updated test2
+        | |
+        | o 944f78da create test3.txt
         |
         x bf0d52a6 (rewritten as 3bd716d5) create test4.txt
         |
@@ -414,3 +416,95 @@ fn test_restack_single_of_many_commits() -> eyre::Result<()> {
 
     Ok(())
 }
+
+/// Regression test for: https://github.com/arxanas/git-branchless/issues/209
+#[test]
+fn test_restack_unobserved_commit() -> eyre::Result<()> {
+    let git = make_git()?;
+
+    git.init_repo_with_options(&GitInitOptions {
+        run_branchless_init: false,
+        ..Default::default()
+    })?;
+
+    git.commit_file("test1", 1)?;
+    git.run(&["checkout", "-b", "foo"])?;
+    git.commit_file("test2", 2)?;
+    git.detach_head()?;
+    git.commit_file("test3", 3)?;
+
+    git.run(&["branchless", "init"])?;
+    {
+        let (stdout, _stderr) = git.run(&["smartlog"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        :
+        O 62fc20d2 (master) create test1.txt
+        |
+        o 96d1c37a (foo) create test2.txt
+        |
+        @ 70deb1e2 create test3.txt
+        "###);
+    }
+
+    // Only abandon `test3` now that it's been observed by the DAG.
+    git.run(&["checkout", "foo"])?;
+
+    git.run(&["commit", "--amend", "-m", "Updated test2"])?;
+    {
+        let (stdout, _stderr) = git.run(&["smartlog"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        :
+        O 62fc20d2 (master) create test1.txt
+        |
+        @ f4229de3 (foo) Updated test2
+        "###);
+    }
+
+    {
+        let (stdout, _stderr) = git.run(&["restack"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        No abandoned commits to restack.
+        No abandoned branches to restack.
+        :
+        O 62fc20d2 (master) create test1.txt
+        |
+        @ f4229de3 (foo) Updated test2
+        "###);
+    }
+
+    Ok(())
+}
+
+/// Regression test for https://github.com/arxanas/git-branchless/issues/236
+#[test]
+fn test_restack_checked_out_branch() -> eyre::Result<()> {
+    let git = make_git()?;
+    git.init_repo()?;
+
+    git.commit_file("test1", 1)?;
+    git.commit_file("test2", 2)?;
+    git.run(&["branch", "foo"])?;
+    git.run(&["checkout", "HEAD^"])?;
+    git.run(&["commit", "--amend", "-m", "test1 amended"])?;
+    git.run(&["checkout", "foo"])?;
+
+    {
+        let (stdout, _stderr) = git.run(&["restack"])?;
+        insta::assert_snapshot!(stdout, @r###"
+        Attempting rebase in-memory...
+        [1/1] Committed as: 59e75818 create test2.txt
+        branchless: processing 2 updates: branch foo, branch master
+        branchless: processing 1 rewritten commit
+        branchless: running command: <git-executable> checkout foo
+        :
+        @ 59e75818 (foo, master) create test2.txt
+        In-memory rebase succeeded.
+        Finished restacking commits.
+        No abandoned branches to restack.
+        :
+        @ 59e75818 (foo, master) create test2.txt
+        "###);
+    }
+
+    Ok(())
+}
